# eric7.UI.InstallInfoDialog

Module implementing a dialog to show information about the installation.

### Global Attributes

None

### Classes

InstallInfoDialog | Class implementing a dialog to show information about the installation.

### Functions

None

## InstallInfoDialog

Class implementing a dialog to show information about the installation.

### Derived from

QDialog, Ui_InstallInfoDialog

### Class Attributes

None

### Class Methods

None

### Methods

InstallInfoDialog | Constructor
__saveData | Private method to save the data.
on_deleteButton_clicked | Private slot deleting the install information file.
on_editButton_toggled | Private slot to switch the dialog into edit mode.
on_saveButton_clicked | Private slot handling the save button press.
on_updateButton_clicked | Private slot to show some upgrade instructions.
reject | Public slot handling the closing of the dialog.
wasLoaded | Public method to check, if the install data was loaded.

### Static Methods

None

#### InstallInfoDialog (Constructor)

InstallInfoDialog(parent=None)

Constructor

parent (QWidget)
  reference to the parent widget

#### InstallInfoDialog.__saveData

__saveData()

Private method to save the data.

#### InstallInfoDialog.on_deleteButton_clicked

on_deleteButton_clicked()

Private slot deleting the install information file.

#### InstallInfoDialog.on_editButton_toggled

on_editButton_toggled(checked)

Private slot to switch the dialog into edit mode.

checked (bool)
  flag giving the button check state

#### InstallInfoDialog.on_saveButton_clicked

on_saveButton_clicked()

Private slot handling the save button press.

#### InstallInfoDialog.on_updateButton_clicked

on_updateButton_clicked()

Private slot to show some upgrade instructions.

#### InstallInfoDialog.reject

reject()

Public slot handling the closing of the dialog.

#### InstallInfoDialog.wasLoaded

wasLoaded()

Public method to check, if the install data was loaded.

Return:
  flag indicating the data was loaded

Return Type:
  bool

Up